summaryrefslogtreecommitdiffstats
path: root/libkmime/kmime_content.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /libkmime/kmime_content.cpp
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkmime/kmime_content.cpp')
-rw-r--r--libkmime/kmime_content.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/libkmime/kmime_content.cpp b/libkmime/kmime_content.cpp
index b6b6229f..7ac10bbb 100644
--- a/libkmime/kmime_content.cpp
+++ b/libkmime/kmime_content.cpp
@@ -85,7 +85,7 @@ void Content::setContent(TQStrList *l)
void Content::setContent(const TQCString &s)
{
- int pos=s.find("\n\n", 0);
+ int pos=s.tqfind("\n\n", 0);
if(pos>-1) {
h_ead=s.left(++pos); //header *must* end with "\n" !!
b_ody=s.mid(pos+1, s.length()-pos-1);
@@ -327,7 +327,7 @@ TQCString Content::encodedContent(bool useCrLf)
e+="\n";
//body
- if(!b_ody.isEmpty()) { //this message tqcontains only one part
+ if(!b_ody.isEmpty()) { //this message contains only one part
Headers::CTEncoding *enc=contentTransferEncoding();
if(enc->needToEncode()) {
@@ -630,7 +630,7 @@ void Content::changeEncoding(Headers::contentEncoding e)
if(decodeText())
enc->setCte(e); // text is not encoded until it's sent or saved so we just set the new encoding
- else { // this content tqcontains non textual data, that has to be re-encoded
+ else { // this content contains non textual data, that has to be re-encoded
if(e!=Headers::CEbase64) {
//kdWarning(5003) << "Content::changeEncoding() : non textual data and encoding != base64 - this should not happen\n => forcing base64" << endl;
@@ -664,14 +664,14 @@ Headers::Generic* Content::getNextHeader(TQCString &head)
bool folded(false);
Headers::Generic *header=0;
- pos1 = head.find(": ");
+ pos1 = head.tqfind(": ");
if (pos1>-1) { //there is another header
pos2=pos1+=2; //skip the name
if (head[pos2]!='\n') { // check if the header is not empty
while(1) {
- pos2=head.find("\n", pos2+1);
+ pos2=head.tqfind("\n", pos2+1);
if(pos2==-1 || pos2==len || ( head[pos2+1]!=' ' && head[pos2+1]!='\t') ) //break if we reach the end of the string, honor folded lines
break;
else